.. OrcaNet documentation master file, created by
   sphinx-quickstart on Tue Nov  6 18:06:28 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. |vspace| raw:: latex

   \vspace{1cm}

.. image:: _static/orcanet_wide_transparent_black.png
   :height: 142px

|vspace|

Welcome to OrcaNet's documentation!
===================================

.. image:: https://git.km3net.de/ml/OrcaNet/badges/master/build.svg
    :target: https://git.km3net.de/ml/OrcaNet/pipelines

| OrcaNet is a part of the Deep Learning efforts for the neutrino telescope KM3NeT.
| Find more information about KM3NeT on http://www.km3net.org.

As of now, these docs only contain the API documentation.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modifiers
   CONTRIBUTING
   Source (Git) <https://git.km3net.de/ml/OrcaNet.git>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
